@@ -1,5 +1,4 @@
-function bar(props__2) {
-}
+function bar(props__2) {}
 var Foo = function Foo1__3() {
     _classCallCheck(this, Foo1__3);
     super();
