@@ -1,5 +1,4 @@
-function a() {
-}
+function a() {}
 function foo() {
     function b__2() {
         a__2();
