@@ -1,7 +1,6 @@
 function foo() {
     return ()=>{
-        function Bar__2() {
-        }
+        function Bar__2() {}
         Bar__2.qux = '';
         return Bar__2;
     };
