@@ -1,7 +1,6 @@
 var Test = function() {
     var Test__2 = function() {
-        function Test__3() {
-        }
+        function Test__3() {}
         return Test__3;
     }();
     return Test__2;
