@@ -1,6 +1,6 @@
 module M {
     export class A__2 {
-        name__0: string;
+        name: string;
     }
     export function F2__2(x__3: number): string {
         return x__3.toString();
@@ -8,7 +8,7 @@ module M {
 }
 module N {
     export class A__4 {
-        id__0: number;
+        id: number;
     }
     export function F2__4(x__5: number): string {
         return x__5.toString();
