@@ -5,8 +5,6 @@ function foo() {
     interface Foo__2 {
         name__0: string;
     }
-    const foo__2 = {
-    } as Foo__2;
+    const foo__2 = {} as Foo__2;
 }
-const bar = {
-} as Foo;
+const bar = {} as Foo;
